==> aws-cdk-lib-2.0.0-rc.14-sources.jar: software/amazon/awscdk/IListProducer.java <==
package software.amazon.awscdk;

/**
 * (experimental) Interface for lazy list producers.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T10:23:55.808Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.IListProducer")
@software.amazon.jsii.Jsii.Proxy(IListProducer.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface IListProducer extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Produce the list value.
     * <p>
     * @param context This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> produce(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.IResolveContext context);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.IListProducer.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * (experimental) Produce the list value.
         * <p>
         * @param context This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> produce(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.IResolveContext context) {
            return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(software.amazon.jsii.Kernel.call(this, "produce", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)), new Object[] { java.util.Objects.requireNonNull(context, "context is required") }))).map(java.util.Collections::unmodifiableList).orElse(null);
        }
    }

    /**
     * Internal default implementation for {@link IListProducer}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends IListProducer {

        /**
         * (experimental) Produce the list value.
         * <p>
         * @param context This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> produce(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.IResolveContext context) {
            return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(software.amazon.jsii.Kernel.call(this, "produce", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)), new Object[] { java.util.Objects.requireNonNull(context, "context is required") }))).map(java.util.Collections::unmodifiableList).orElse(null);
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/IListProducer.java <==
package software.amazon.awscdk;

/**
 * Interface for lazy list producers.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:06.875Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.IListProducer")
@software.amazon.jsii.Jsii.Proxy(IListProducer.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IListProducer extends software.amazon.jsii.JsiiSerializable {

    /**
     * Produce the list value.
     * <p>
     * @param context This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> produce(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.IResolveContext context);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.IListProducer.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Produce the list value.
         * <p>
         * @param context This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public final @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> produce(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.IResolveContext context) {
            return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(software.amazon.jsii.Kernel.call(this, "produce", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)), new Object[] { java.util.Objects.requireNonNull(context, "context is required") }))).map(java.util.Collections::unmodifiableList).orElse(null);
        }
    }

    /**
     * Internal default implementation for {@link IListProducer}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends IListProducer {

        /**
         * Produce the list value.
         * <p>
         * @param context This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> produce(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.IResolveContext context) {
            return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(software.amazon.jsii.Kernel.call(this, "produce", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)), new Object[] { java.util.Objects.requireNonNull(context, "context is required") }))).map(java.util.Collections::unmodifiableList).orElse(null);
        }
    }
}
